import json
import subprocess


def split_video(video_url: str, save_path: str, frames: int):
    """
    将视频拆分成图片帧，并保存到指定的目录。
    :param video_url: 视频url
    :param save_path: 保存的目录
    :param frames: 需要拆分的帧数
    """
    # 使用ffmpeg命令将视频分割成帧
    cmd = f'ffmpeg -i {video_url} -vf fps={frames} {save_path}/frame_%04d.png'
    subprocess.call(cmd, shell=True)

    # 使用ffmpeg命令将视频中的音频分离出来
    cmd = f'ffmpeg -i {video_url} -vn -acodec copy {save_path}/audio.aac'
    subprocess.call(cmd, shell=True)


def get_video_resolution(video_file_path):
    """
    # from tybase.tools.video_utils import get_video_resolution
    # 获取视频的分辨率(本地), 用于视频加水印的时候会用到

    :param video_file_path: 本地的视频的路径
    :return: (width, height)
    """
    command = ["ffprobe",
               "-v", "error",
               "-select_streams", "v:0",
               "-show_entries", "stream=width,height",
               "-of", "json",
               video_file_path]

    output = subprocess.check_output(command).decode("utf-8")
    video_info = json.loads(output)

    width = video_info['streams'][0]['width']
    height = video_info['streams'][0]['height']

    return width, height
